@@ -5,7 +5,7 @@ from .svdpp import SVDpp
 from .als import ALS
 from .bpr import BPR
 from .ncf import NCF
-from .youtube_match import YouTubeMatch
+from .youtube_retrieval import YouTuBeRetrieval
 from .youtube_ranking import YouTubeRanking
 from .fm import FM
 from .wide_deep import WideDeep
@@ -16,3 +16,25 @@ from .knn_embed import KnnEmbedding, KnnEmbeddingApproximate
 from .rnn4rec import RNN4Rec
 from .caser import Caser
 from .wave_net import WaveNet
+
+__all__ = [
+    "UserCF",
+    "ItemCF",
+    "SVD",
+    "SVDpp",
+    "ALS",
+    "BPR",
+    "NCF",
+    "YouTuBeRetrieval",
+    "YouTubeRanking",
+    "FM",
+    "WideDeep",
+    "DeepFM",
+    "AutoInt",
+    "DIN",
+    "KnnEmbedding",
+    "KnnEmbeddingApproximate",
+    "RNN4Rec",
+    "Caser",
+    "WaveNet"
+]
