@@ -9,10 +9,10 @@ author: massquantity
 from itertools import islice
 import os
 import numpy as np
-import tensorflow.compat.v1 as tf
+import tensorflow as tf2
 from tensorflow.keras.initializers import (
+    zeros as tf_zeros,
     truncated_normal as tf_truncated_normal,
-    orthogonal as tf_orthogonal,
     glorot_normal as tf_glorot_normal
 )
 from .base import Base, TfMixin
@@ -27,6 +27,7 @@ from ..data.sequence import user_last_interacted
 from ..utils.sampling import PairwiseSamplingSeq
 from ..utils.misc import time_block, colorize
 from ..utils.misc import count_params, assign_oov_vector
+tf = tf2.compat.v1
 tf.disable_v2_behavior()
 
 
@@ -147,7 +148,7 @@ class RNN4Rec(Base, TfMixin, EvalMixin):
         self.item_biases = tf.get_variable(
             name="item_biases",
             shape=[self.n_items],
-            initializer=tf.zeros,
+            initializer=tf_zeros,
             regularizer=self.reg
         )
         self.item_weights = tf.get_variable(
